@@ -22,7 +22,7 @@ LearnerSurvKaplan = R6Class("LearnerSurvKaplan",
         predict_types = c("crank", "distr"),
         feature_types = c("logical", "integer", "numeric", "character", "factor", "ordered"),
         properties = "missings",
-        packages = c("survival", "distr6"),
+        packages = c("survival", "distr6", "pracma"),
         man = "mlr3proba::mlr_learners_surv.kaplan"
       )
     }
