@@ -29,10 +29,13 @@ MeasureDens = R6Class("MeasureDens",
   public = list(
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
-    initialize = function(id, range, minimize = NA, aggregator = NULL, properties = character(), predict_type = "pdf", task_properties = character(0L), packages = character(0L)) {
+    initialize = function(id, range, minimize = NA, aggregator = NULL, properties = character(),
+                          predict_type = "pdf", task_properties = character(),
+                          packages = character(), man = NA_character_) {
       super$initialize(id,
         task_type = "dens", range = range, minimize = minimize, aggregator = aggregator,
-        properties = properties, predict_type = predict_type, task_properties = task_properties, packages = packages)
+        properties = properties, predict_type = predict_type, task_properties = task_properties,
+        packages = packages, man = man)
     }
   )
 )
