@@ -9,12 +9,16 @@
 #' @template param_packages
 #' @template param_predict_type
 #' @template param_measure_properties
+#' @template param_man
+#' @template param_se
 #' @export
 MeasureSurvIntegrated = R6Class("MeasureSurvIntegrated",
   inherit = MeasureSurv,
   public = list(
     #' @description This is an abstract class that should not be constructed directly.
-    initialize = function(integrated = TRUE, times, method = 2, id, range, minimize, packages, predict_type, properties) {
+    initialize = function(integrated = TRUE, times, method = 2, id, range, minimize, packages,
+                          predict_type, properties = character(), man = NA_character_,
+                          se = FALSE) {
       if (class(self)[[1]] == "MeasureSurvIntegrated") {
         stop("This is an abstract class that should not be constructed directly.")
       }
@@ -25,7 +29,9 @@ MeasureSurvIntegrated = R6Class("MeasureSurvIntegrated",
         minimize = minimize,
         packages = packages,
         predict_type = predict_type,
-        properties = properties
+        properties = properties,
+        man = man,
+        se = se
       )
 
       assertFlag(integrated)
@@ -64,9 +70,7 @@ MeasureSurvIntegrated = R6Class("MeasureSurvIntegrated",
       } else {
         assertFlag(integrated)
         if (!integrated & length(self$times) > 1) {
-          stop(sprintf(
-            "For the non-integrated score, only a single time-point can be returned. Currently self$times = %s",
-            paste0("c(", paste0(self$times, collapse = ", "), ").")))
+          stop(sprintf("For the non-integrated score, only a single time-point can be returned. Currently self$times = %s", paste0("c(", paste0(self$times, collapse = ", "), ")."))) # nolint
         }
         private$.integrated = integrated
       }
