@@ -6,7 +6,6 @@ test_that("autotest", {
   expect_true(result, info = result$error)
 })
 
-
 data = data.frame("A" = c(0.2, 0.4, 0.6, 0.8, 1, 1.2, 1.4, 1.6))
 task = TaskDens$new(id = "a", data, target = "A")
 lrn = lrn("dens.kde", bandwidth = 0.1, kernel = "Norm")
@@ -25,7 +24,7 @@ test_that("pdf", {
 
 test_that("bw", {
   set.seed(1)
-  lrn = lrn("dens.kde")
+  lrn = lrn("dens.kde", kernel = "Norm")
   lrn$train(task)
   d = stats::density(data$A, bw = 0.2908909)
   task_test = TaskDens$new(id = "a", data.frame(a = d$x[20]), target = "a")
